use "trade_final.dta", replace
set more off

sort ccode year
xtset ccode year

global baseline "d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global covariate "loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global cond "r cluster(ccode)"
global rec ""

eststo clear
global var "TOTexport_goods_ubiquity_adj"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex replace

global var "ShannonEntropy"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex append

global var "HHI"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex append

global var "exp_n_goods_c_weight"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex append

global var "exp_n_goods_l_RCA"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex append

global var "exp_n_goods_c_RCA"
gen f$var=F.$var
gen frx_$var=F.rx_$var
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline1", tex append
esttab using "Results/table/t1a.tex", replace keep(ea dem) order(dem ea) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t1a_full.tex", replace keep(ea dem $covariate) order(dem ea $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

// five-year election restriction
eststo clear
global var "TOTexport_goods_ubiquity_adj"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex replace

global var "ShannonEntropy"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex append

global var "HHI"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex append

global var "exp_n_goods_c_weight"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex append

global var "exp_n_goods_l_RCA"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex append

global var "exp_n_goods_c_RCA"
eststo: reg F.$var $baseline demx eax $rec, $cond
outreg2 using "Results/regression/baseline1_alt", tex append
esttab using "Results/table/t1a_alt.tex", replace keep(eax demx) order(demx eax) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t1a_full_alt.tex", replace keep(eax demx $covariate) order(demx eax $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

eststo clear
global var "TOTexport_goods_ubiquity_adj"
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline1_his", tex replace

global var "ShannonEntropy"
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline1_his", tex append

global var "HHI"
eststo: reg F.$var $baseline dem_avg ea_avg$rec, $cond
outreg2 using "Results/regression/baseline1_his", tex append

global var "exp_n_goods_c_weight"
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline1_his", tex append

global var "exp_n_goods_l_RCA"
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline1_his", tex append

global var "exp_n_goods_c_RCA"
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline1_his", tex append
esttab using "Results/table/t1b.tex", replace keep(dem_avg ea_avg) order(dem_avg ea_avg) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t1b_full.tex", replace keep(ea_avg dem_avg $covariate) order(dem_avg ea_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

global iv "nbrdem regiondem nbrea regionea"
global iv_avg "nbrdem_avg regiondem_avg nbrea_avg regionea_avg"
global iv_alt "nbrdem nbrea"
global iv_avg_alt "nbrdem_avg nbrea_avg"
global var "exp_n_goods_c_RCA"
global tech "liml"

eststo clear
eststo: reg F.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/baseline2", tex replace
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/baseline2", tex append
eststo: reg F.$var $baseline dem eax $rec, $cond
outreg2 using "Results/regression/baseline2", tex append
eststo: reg F.$var $baseline dem_avg eax_avg $rec, $cond
outreg2 using "Results/regression/baseline2", tex append
eststo: ivreg2 F.$var $baseline (dem ea = $iv) $rec, $cond $tech ffirst
outreg2 using "Results/regression/baseline2", tex append
eststo: ivreg2 F.$var $baseline (dem_avg ea_avg = $iv_avg) $rec, $cond $tech ffirst
outreg2 using "Results/regression/baseline2", tex append
eststo: ivreg2 F.$var $baseline (dem eax = $iv) $rec, $cond $tech ffirst
outreg2 using "Results/regression/baseline2", tex append
eststo: ivreg2 F.$var $baseline (dem_avg eax_avg = $iv_avg) $rec, $cond $tech ffirst
outreg2 using "Results/regression/baseline2", tex append
esttab using "Results/table/t1c.tex", replace keep(ea dem ea_avg dem_avg eax eax_avg $covariate) order(dem ea dem_avg ea_avg eax eax_avg $covariate) label r2 scalars(idp widstat arfp) star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

// display the first stage results (also with the alternative specification of iv, using neighboring countries only)
ivreg2 F.$var $baseline (dem ea = $iv) $rec, $cond $tech first
ivreg2 F.$var $baseline (dem_avg ea_avg = $iv_avg) $rec, $cond $tech first
ivreg2 F.$var $baseline (dem ea = $iv_alt) $rec, $cond $tech first
ivreg2 F.$var $baseline (dem_avg ea_avg = $iv_avg_alt) $rec, $cond $tech first

//Sensitivity analysis, Oster 2015
global var "CIE"
//trade
global var "TOTexport_goods_ubiquity_adj"
global var "ShannonEntropy"
global var "HHI"
global var "exp_w_goods_c_weight"
global var "exp_r_goods_c_weight"
global var "exp_n_goods_c_weight"
global var "exp_w_goods_c_RCA"
global var "exp_r_goods_c_RCA"
global var "exp_n_goods_c_RCA"

global var "TOTexport_goods_ubiquity_adj"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem 
scalar delta3=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta4=r(output)
global var "ShannonEntropy"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem
scalar delta5=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta6=r(output)
global var "HHI"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem
scalar delta7=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta8=r(output)
global var "exp_n_goods_c_weight"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem
scalar delta9=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta10=r(output)
global var "exp_n_goods_l_RCA"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem
scalar delta11=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta12=r(output)
global var "exp_n_goods_c_RCA"
eststo: quietly reg F.$var $baseline dem ea $rec
psacalc delta dem 
scalar delta13=r(output)
eststo: quietly reg F.$var $baseline dem_avg ea_avg $rec
psacalc delta dem_avg
scalar delta14=r(output)

matrix DELTA = J(2,6,0)
local i=3
forvalues j = 1/6 { 
	matrix DELTA[1,`j'] = delta`i'
	local i=`i'+1
	matrix DELTA[2,`j'] = delta`i'
	local i=`i'+1
}
mat2txt , matrix(DELTA) saving("Results/table/sensitivity") title("DELTA") replace


/*Part 2*/
/*Main robustness checks*/
//authoritarian regimes: leadership groups (Geddes et al.), party, military, royal, and personalist
global robustcheck_geddes "d_geddesmilitary d_geddesparty d_geddesmonarchy d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol resourcesdep_hm major_oil_producer aid communist"
global robustcheck_geddes_elf "d_geddesmilitary d_geddesparty d_geddesmonarchy d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
//authoritarian regimes: leadership groups (Cheibub et al.), civilian, military and royal.
global robustcheck_group "dd_civilian dd_military dd_royal dd_democracy d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol resourcesdep_hm major_oil_producer aid communist"
//further disintegration of electoral autocracy and other authoritarian institutions
global robustcheck_ea_sub "dd_multileg2 dd_nomultileg2 dd_legonly2 dd_singleparty2 d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol resourcesdep_hm major_oil_producer aid communist"
global robustcheck_ea_sub_elf "dd_multileg2 dd_nomultileg2 dd_legonly2 dd_singleparty2 d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"

// the chance of having competitive electoral institutions
// global covariate "loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
eststo clear
eststo: logit F.ea F.dd_civilian F.dd_military F.dd_royal $covariate i.year if dd_democracy==0, cluster(ccode)
outreg2 using "Results/regression/prob_ea", tex replace
eststo: logit F.ea F.d_geddesparty F.d_geddesmilitary F.d_geddesmonarchy $covariate i.year if d_geddesdem==0, cluster(ccode)
outreg2 using "Results/regression/prob_ea", tex append
esttab using "Results/table/t3_probea.tex", replace keep(F.dd_civilian F.dd_military F.d_geddesparty F.d_geddesmilitary F.d_geddesmonarchy $covariate) order(F.dd_civilian F.dd_military F.d_geddesparty F.d_geddesmilitary F.d_geddesmonarchy $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

encode geddes_type2, gen(geddes_type2c)
mlogit geddes_type2c $covariate d_year147-d_year211 if d_geddesdem==0, cluster(ccode)

global rec_ge "if d_valid==1"

eststo clear
eststo: reg F.$var dem $robustcheck_geddes_elf $rec_ge, $cond
outreg2 using "Results/regression/institution", tex replace
eststo: reg F.$var dem $robustcheck_ea_sub_elf $rec, $cond
outreg2 using "Results/regression/institution", tex append
eststo: xtreg F.$var dem $robustcheck_geddes $rec_ge, $cond
outreg2 using "Results/regression/institution", tex replace
eststo: xtreg F.$var dem $robustcheck_ea_sub $rec, $cond
outreg2 using "Results/regression/institution", tex append
eststo: xtreg F.$var dem $robustcheck_geddes $rec_ge, $cond fe
outreg2 using "Results/regression/institution", tex replace
eststo: xtreg F.$var dem $robustcheck_ea_sub $rec, $cond fe
outreg2 using "Results/regression/institution", tex append
esttab using "Results/table/t3.tex", replace keep(dem $geddes $ea_sub) order(dem $geddes $ea_sub) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t3_full.tex", replace keep(dem $geddes $ea_sub $covariate) order(dem $geddes $ea_sub $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

//state capacity
global capacity_rpea "rpe_agri d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global capacity_rpeb "rpe_gdp d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global capacity_rpec "rpe_gdp_oecd d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global capacity_rpra "rpr_work d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global capacity_rprb "rpr_eap d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol ELF resourcesdep_hm major_oil_producer aid communist"
global capacity_cap "Capacity d_year147-d_year211 loggdp cspv_civviol resourcesdep_hm urban_wdi ELF gdp_grow lnpop communist aid major_oil_producer"

eststo clear
eststo: reg F.$var dem ea $capacity_rpea $rec, $cond
outreg2 using "Results/regression/capacity", tex replace
eststo: reg F.$var dem ea $capacity_rpeb $rec, $cond
outreg2 using "Results/regression/capacity", tex append
eststo: reg F.$var dem ea $capacity_rpec $rec, $cond
outreg2 using "Results/regression/capacity", tex append
eststo: reg F.$var dem ea $capacity_rpra $rec, $cond
outreg2 using "Results/regression/capacity", tex append
eststo: reg F.$var dem ea $capacity_rprb $rec, $cond
outreg2 using "Results/regression/capacity", tex append
eststo: reg F.$var dem ea $capacity_cap $rec, $cond
outreg2 using "Results/regression/capacity", tex append
esttab using "Results/table/t4.tex", replace keep(ea dem $capacity_list) order(dem ea $capacity_list) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t4_full.tex", replace keep(ea dem $capacity_list $covariate) order(dem ea $capacity_list $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

// interacting electoral autocracy with state capacity
eststo clear
eststo: reg F.$var dem##c.Capacity ea##c.Capacity $capacity_cap $rec, $cond
outreg2 using "Results/regression/capacity_interact", tex replace
eststo: xtreg F.$var dem##c.Capacity ea##c.Capacity $capacity_cap $rec, $cond re
outreg2 using "Results/regression/capacity_interact", tex append
eststo: xtreg F.$var dem##c.Capacity ea##c.Capacity $capacity_cap i.region $rec, $cond re
outreg2 using "Results/regression/capacity_interact", tex append
eststo: xtreg F.$var dem##c.Capacity ea##c.Capacity $capacity_cap $rec, $cond fe
outreg2 using "Results/regression/capacity_interact", tex append
esttab using "Results/table/t4b.tex", replace keep(1.ea 1.dem Capacity 1.dem#c.Capacity 1.ea#c.Capacity) order(1.ea 1.dem Capacity 1.dem#c.Capacity 1.ea#c.Capacity) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
esttab using "Results/table/t4b_full.tex", replace keep(1.ea 1.dem Capacity 1.dem#c.Capacity 1.ea#c.Capacity $covariate) order(1.ea 1.dem Capacity 1.dem#c.Capacity 1.ea#c.Capacity $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

/*Main robustness checks 2: Alternative Measurement of Regime Types: Polity Score (as continuous variable) */
global robustcheck2 "d_year147-d_year211 loggdp gdp_grow lnpop urban_wdi cspv_civviol resourcesdep_hm major_oil_producer aid communist"
global covariate2 "loggdp gdp_grow lnpop urban_wdi cspv_civviol resourcesdep_hm major_oil_producer aid communist"

eststo clear
eststo: reg F.$var $robustcheck2 polity2 $rec, $cond
outreg2 using "Results/regression/polity", tex replace
eststo: xtreg F.$var $robustcheck2 polity2 $rec, $cond re
outreg2 using "Results/regression/polity", tex append
eststo: xtreg F.$var $robustcheck2 polity2 i.region $rec, $cond re
outreg2 using "Results/regression/polity", tex append
eststo: xtreg F.$var $robustcheck2 polity2 $rec, $cond fe
outreg2 using "Results/regression/polity", tex append
esttab using "Results/table/t4c_full.tex", replace keep(polity2 $covariate2) order(polity2 $covariate2) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

 
/*Main robustness checks 3: fe, be, re (w/o ar1) and lagged dependent variable*/
eststo clear
eststo: xtreg F.$var $robustcheck2 dem ea $rec, $cond fe
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex replace
eststo: xtreg F.$var $robustcheck2 dem ea $rec, $cond re
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem_avg ea_avg $rec, $cond fe
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem_avg ea_avg $rec, $cond re
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem ea dem#c.resources ea#c.resources $rec, $cond fe
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem ea dem#c.resources ea#c.resources $rec, $cond re
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 polity2 $rec, $cond fe
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 polity2 $rec, $cond re
outreg2 using "Results/regression/fe_re", adds(r2within, e(r2_w)) tex append
esttab using "Results/table/t5.tex", replace order(dem ea dem_avg ea_avg polity2 $covariate2) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

eststo clear
eststo: xtreg F.$var $robustcheck2 dem ea ELF $rec, $cond re
outreg2 using "Results/regression/re_ELF", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem_avg ea_avg ELF $rec, $cond re
outreg2 using "Results/regression/re_ELF", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 dem ea dem#c.resources ea#c.resources ELF $rec, $cond re
outreg2 using "Results/regression/re_ELF", adds(r2within, e(r2_w)) tex append
eststo: xtreg F.$var $robustcheck2 polity2 ELF $rec, $cond re
outreg2 using "Results/regression/re_ELF", adds(r2within, e(r2_w)) tex append
esttab using "Results/table/t5elf.tex", replace order(dem ea dem_avg ea_avg polity2 $covariate2 ELF) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

// display the first stage results 
xtivreg2 F.$var $robustcheck2 (dem ea = $iv) $rec, fe cluster(ccode) first
xtivreg F.$var $robustcheck2 (dem ea = $iv) $rec, re vce(robust) first
xtivreg2 F.$var $robustcheck2 (dem_avg ea_avg = $iv_avg) $rec, fe cluster(ccode) first
xtivreg F.$var $robustcheck2 (dem_avg ea_avg = $iv_avg) $rec, re vce(robust) first

eststo clear
eststo: xtregar F.$var $robustcheck2 dem ea $rec, fe
eststo: xtregar F.$var $robustcheck2 dem ea $rec, re
eststo: xtregar F.$var $robustcheck2 dem_avg ea_avg $rec, fe
eststo: xtregar F.$var $robustcheck2 dem_avg ea_avg $rec, re
eststo: xtregar F.$var $robustcheck2 dem ea dem#c.resources ea#c.resources $rec, fe
eststo: xtregar F.$var $robustcheck2 dem ea dem#c.resources ea#c.resources $rec, re
eststo: xtregar F.$var $robustcheck2 polity2 $rec, fe
eststo: xtregar F.$var $robustcheck2 polity2 $rec, re
esttab using "Results/table/t5ar1.tex", replace order(dem ea dem_avg ea_avg polity $covariate2) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


//LDV
eststo clear
eststo: reg F.$var $var $baseline dem ea $rec, $cond 
outreg2 using "Results/regression/LDV", tex replace
eststo: reg F.$var $var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/LDV", tex append
eststo: reg F.$var $var l.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/LDV", tex append
eststo: reg F.$var $var l.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/LDV", tex append
eststo: reg F.$var $var l.$var l2.$var $baseline dem ea $rec, $cond
outreg2 using "Results/regression/LDV", tex append
eststo: reg F.$var $var l.$var l2.$var $baseline dem_avg ea_avg $rec, $cond
outreg2 using "Results/regression/LDV", tex append
eststo: reg F.$var $var frx_$var $baseline dem ea $rec, $cond 
outreg2 using "Results/regression/LDV", tex replace
eststo: reg F.$var $var i.region $baseline dem ea $rec, $cond 
outreg2 using "Results/regression/LDV", tex replace
esttab using "Results/table/t6a.tex", replace keep(ea dem ea_avg dem_avg $covariate) order(dem ea dem_avg ea_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

eststo clear
eststo: xtreg F.$var $var $robustcheck2 dem ea $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var $robustcheck2 dem_avg ea_avg $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var $robustcheck2 dem ea $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var $robustcheck2 dem_avg ea_avg $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var l2.$var $robustcheck2 dem ea $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var l2.$var $robustcheck2 dem_avg ea_avg $rec, $cond re
outreg2 using "Results/regression/LDV", tex append
esttab using "Results/table/t6b.tex", replace keep(ea dem ea_avg dem_avg $covariate2) order(dem ea dem_avg ea_avg $covariate2) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

eststo clear
eststo: xtreg F.$var $var $robustcheck2 dem ea $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var $robustcheck2 dem_avg ea_avg $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var $robustcheck2 dem ea $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var $robustcheck2 dem_avg ea_avg $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var l2.$var $robustcheck2 dem ea $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
eststo: xtreg F.$var $var l.$var l2.$var $robustcheck2 dem_avg ea_avg $rec, $cond fe
outreg2 using "Results/regression/LDV", tex append
esttab using "Results/table/t6c.tex", replace keep(ea dem ea_avg dem_avg $covariate2) order(dem ea dem_avg ea_avg $covariate2) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 3*/
//Driscoll-Kraay standard error (Spatial Dynamics, control for region average)
global tech "liml partial(d_year147-d_year211)"
global nlag "3"

eststo clear
eststo: xtscc f$var frx_$var $baseline dem ea, lag($nlag)
outreg2 using "Results/regression/Driscoll-Kraay", tex replace
eststo: xtscc f$var frx_$var $robustcheck2 dem ea, lag($nlag) fe
outreg2 using "Results/regression/Driscoll-Kraay", tex append
eststo: xtscc f$var frx_$var $baseline dem_avg ea_avg, lag($nlag)
outreg2 using "Results/regression/Driscoll-Kraay", tex append
eststo: xtscc f$var frx_$var $robustcheck2 dem_avg ea_avg, lag($nlag) fe
outreg2 using "Results/regression/Driscoll-Kraay", tex append

esttab using "Results/table/t7.tex", replace keep(ea dem dem_avg ea_avg $covariate) order(dem ea dem_avg ea_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 4*/
//Exclusion restriction checks for closed autocracies
eststo clear
global var "exp_n_goods_c_RCA"
global rec "if dem==0 & ea==0"
eststo: quietly reg F.$var nbrdem $baseline $rec, $cond
eststo: quietly reg F.$var nbrea $baseline $rec, $cond
eststo: quietly reg F.$var regiondem $baseline $rec, $cond
eststo: quietly reg F.$var regionea $baseline $rec, $cond
eststo: quietly reg F.$var nbrea regionea nbrdem regiondem $baseline $rec, $cond
esttab using "Results/table/t8.tex", replace keep(nbrdem nbrea regionea regiondem) order(nbrdem nbrea regiondem regionea) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


//Direct effect of IVs (fn.18)
eststo clear
global var "exp_n_goods_c_RCA"
global rec ""
quietly reg ea $baseline dem $iv $rec, $cond
predict yy
quietly reg ea_avg $baseline dem_avg $iv_avg $rec, $cond
predict yy_avg
eststo: reg F.$var $baseline dem ea yy $rec, $cond
eststo: reg F.$var $baseline dem ea $iv $rec, $cond
eststo: reg F.$var $baseline dem_avg ea_avg yy_avg $rec, $cond
eststo: reg F.$var $baseline dem_avg ea_avg $iv_avg $rec, $cond
esttab using "Results/table/t9.tex", replace keep(dem ea yy $iv dem_avg ea_avg yy_avg $iv_avg) order(dem ea yy $iv dem_avg ea_avg yy_avg $iv_avg) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 5: Country-specific trends*/
eststo clear
global var "exp_n_goods_c_RCA"
eststo: reg F.$var d_year147-d_year211 dem ea i.ccode#c.cyear $rec, $cond 
eststo: xtreg F.$var d_year147-d_year211 dem ea i.ccode#c.cyear $rec, $cond re
eststo: xtreg F.$var d_year147-d_year211 dem ea i.ccode#c.cyear $rec, $cond fe
eststo: reg F.$var d_year147-d_year211 dem_a ea_a i.ccode#c.cyear $rec, $cond 
eststo: xtreg F.$var d_year147-d_year211 dem_a ea_a i.ccode#c.cyear $rec, $cond re
eststo: xtreg F.$var d_year147-d_year211 dem_a ea_a i.ccode#c.cyear $rec, $cond fe
esttab using "Results/table/t10.tex", replace keep(dem ea dem_avg ea_avg) order(dem ea dem_avg ea_avg) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 6: Subsample Analysis */
//mature democracy out
global rec "if dem_mature==0"

eststo clear
eststo: reg F.$var $baseline dem ea $rec, $cond
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
eststo: ivreg2 F.$var $baseline (dem ea = $iv) $rec, $cond $tech ffirst
eststo: ivreg2 F.$var $baseline (dem_avg ea_avg = $iv_avg) $rec, $cond $tech ffirst
esttab using "Results/table/t11.tex", replace keep(dem ea dem_avg ea_avg $covariate) order(dem ea dem_avg ea_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

//oil exporter, by 2000.
global rec "if oil_producer_2000==1"

eststo clear
eststo: reg F.$var $baseline dem ea $rec, $cond
eststo: reg F.$var $baseline dem_avg ea_avg $rec, $cond
eststo: ivreg2 F.$var $baseline (dem ea = $iv) $rec, $cond $tech ffirst
eststo: ivreg2 F.$var $baseline (dem_avg ea_avg = $iv_avg) $rec, $cond $tech ffirst
esttab using "Results/table/t12.tex", replace keep(dem ea dem_avg ea_avg $covariate) order(dem ea dem_avg ea_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 7: GMM Arellano-Bond */
mata: mata set matafavor speed, perm
//difference
eststo clear
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 2)) iv($robustcheck2 dem ea) nolevel $cond
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 3)) iv($robustcheck2 dem ea) nolevel $cond
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 4)) iv($robustcheck2 dem ea) nolevel $cond
eststo: xtabond2 F.$var $var L.$var L2.$var $robustcheck2 dem ea, gmm($var L.$var L2.$var, lag(3 5)) iv($robustcheck2 dem ea) nolevel $cond
esttab using "Results/table/t13.tex", replace keep(dem ea) order(dem ea) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

//system
eststo clear
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 2)) iv($robustcheck2 dem ea) $cond
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 3)) iv($robustcheck2 dem ea) $cond
eststo: xtabond2 F.$var $var $robustcheck2 dem ea, gmm($var, lag(1 4)) iv($robustcheck2 dem ea) $cond
eststo: xtabond2 F.$var $var L.$var L2.$var $robustcheck2 dem ea, gmm($var L.$var L2.$var, lag(3 5)) iv($robustcheck2 dem ea) $cond
esttab using "Results/table/t13b.tex", replace keep(dem ea) order(dem ea) label star(+ 0.10 * 0.05 ** 0.01 *** 0.001)


/*Part 8: Long Term Effect: 5-year and 10-year Moving Average*/
generate moveavg5 = (F5.$var + F4.$var + F3.$var + F2.$var + F1.$var ) / 5
generate moveavg10 = (F10.$var + F9.$var + F8.$var + F7.$var + F6.$var + F5.$var + F4.$var + F3.$var + F2.$var + F1.$var) / 10

global rec "if year==1965|year==1970|year==1975|year==1980|year==1985|year==1990|year==1995|year==2000|year==2005"

eststo clear
eststo: xtreg moveavg5 $robustcheck2 dem $rec, $cond re
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex replace
eststo: xtreg moveavg5 $robustcheck2 dem_avg $rec, $cond re
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex append
eststo: xtreg moveavg5 $robustcheck2 dem $rec, $cond fe
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex append
eststo: xtreg moveavg5 $robustcheck2 dem_avg $rec, $cond fe
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex append

global rec "if year==1970|year==1980|year==1990|year==2000"

eststo: xtreg moveavg10 $robustcheck2 dem $rec, $cond re
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex append
eststo: xtreg moveavg10 $robustcheck2 dem_avg $rec, $cond re
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w)) tex append
eststo: xtreg moveavg10 $robustcheck2 dem $rec, $cond fe
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w))  tex append
eststo: xtreg moveavg10 $robustcheck2 dem_avg $rec, $cond fe
outreg2 using "Results/regression/moving_avgfe", adds(r2within, e(r2_w))  tex append
esttab using "Results/table/t14.tex", replace keep(dem dem_avg $covariate) order(dem dem_avg $covariate) label r2 star(+ 0.10 * 0.05 ** 0.01 *** 0.001)
drop moveavg5 moveavg10
eststo clear
